@@ -48,9 +48,7 @@ PotdEngine::PotdEngine(QObject *parent, const QVariantList &args)
     m_checkDatesTimer->setInterval(10 * 60 * 1000); // check every 10 minutes
     m_checkDatesTimer->start();
 
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("potd"), [](const KPluginMetaData &md) {
-        return md.serviceTypes().contains(QStringLiteral("PlasmaPoTD/Plugin"));
-    });
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("potd"));
 
     for (const auto &metadata : plugins) {
         QString provider = metadata.value(QLatin1String("X-KDE-PlasmaPoTDProvider-Identifier"));
@@ -194,6 +192,6 @@ void PotdEngine::checkDayChanged()
     }
 }
 
-K_EXPORT_PLASMA_DATAENGINE_WITH_JSON(potdengine, PotdEngine, "plasma-dataengine-potd.json")
+K_PLUGIN_CLASS_WITH_JSON(PotdEngine, "plasma-dataengine-potd.json")
 
 #include "potd.moc"
